@@ -8,12 +8,18 @@ start time than mere basic arithmetic, but just enought to make it more useful f
 In implementation, the focus is on ease of use, not efficiency.
 """
 
-from crocodile.toolbox import *
-from crocodile import __version__
-import random
+from crocodile.core import *
+from crocodile.file_management import *
+from crocodile.meta import *
+# import crocodile.environment as env
+from crocodile.matplotlib_management import *
+import crocodile.toolbox as tb
 
-print(f"Crocodile Shell {__version__}")
+import numpy as np
+import pandas as pd
+
+
+print(f"Crocodile Shell {__import__('crocodile').__version__}")
 # link to tutorial or github
 print(f"Made with ❤️")
-print(random.choice(P(__file__).parent.joinpath("art").search()).read_text())
-
+print(P(__file__).parent.joinpath("art").search().sample(size=1)[0].read_text())
